@@ -1,25 +1,21 @@
 /*-
-* syslog-rs - a syslog client translated from libc to rust
-* Copyright (C) 2021  Aleksandr Morozov
-* Copyright (C) 2021  RELKOM s.r.o
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Lesser General Public
-* License as published by the Free Software Foundation; either
-* version 3 of the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Lesser General Public License for more details.
-* 
-* You should have received a copy of the GNU Lesser General Public License
-* along with this program; if not, write to the Free Software Foundation,
-* Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * syslog-rs - a syslog client translated from libc to rust
+ * Copyright (C) 2020  Aleksandr Morozov, RELKOM s.r.o
+ * Copyright (C) 2021-2022  Aleksandr Morozov
+ * 
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ *  file, You can obtain one at https://mozilla.org/MPL/2.0/.
+ */
+
 
 //! syslog-rs
 //! 
+//! Since v 0.2.4 this project is relicensed with MPLv2.0.
+//! The contributors and authors agreed to change license:
+//! Aleksandr Morozov
+//! RELKOM s.r.o
+//! 
 //! An implementation of the syslog from glibc/libc like it was designed in
 //! in both system libraries. The API is almost compatible with what is in
 //! libc/glibc.
@@ -59,7 +55,7 @@
 extern crate crossbeam;
 extern crate chrono;
 extern crate nix;
-extern crate libc;
+//extern crate libc;
 #[macro_use] extern crate lazy_static;
 
 #[cfg(feature = "use_async")]
